Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(901)

Unified Diff: chrome/browser/ui/cocoa/tab_contents/favicon_util_mac.h

Issue 11305008: Remove TabContents from TabStripModelObserverBridge. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/tab_contents/favicon_util_mac.h
diff --git a/chrome/browser/ui/cocoa/tab_contents/favicon_util_mac.h b/chrome/browser/ui/cocoa/tab_contents/favicon_util_mac.h
index c975f716ca06a2db701a15f299a93d2a2692959d..99c7e4061fbab013dfec1d0045310dae7fafc26b 100644
--- a/chrome/browser/ui/cocoa/tab_contents/favicon_util_mac.h
+++ b/chrome/browser/ui/cocoa/tab_contents/favicon_util_mac.h
@@ -6,14 +6,17 @@
#define CHROME_BROWSER_UI_COCOA_TAB_CONTENTS_FAVICON_UTIL_MAC_H_
@class NSImage;
-class TabContents;
+
+namespace content {
+class WebContents;
+}
namespace mac {
// Returns an autoreleased favicon for a given TabContents. If |contents|
// is NULL or there's no favicon for the NavigationEntry, this will return the
// default image.
-NSImage* FaviconForTabContents(TabContents* contents);
+NSImage* FaviconForWebContents(content::WebContents* contents);
} // namespace mac

Powered by Google App Engine
@@ -6,14 +6,17 @@
namespace mac {
-// Returns an autoreleased favicon for a given TabContents. If |contents|
+// Returns an autoreleased favicon for a given WebContents. If |contents|
// is NULL or there's no favicon for the NavigationEntry, this will return the
// default image.
This is Rietveld 408576698